summaryrefslogtreecommitdiffstats
path: root/qtsharp/src/bindings/static/QToolButton.cs
diff options
context:
space:
mode:
Diffstat (limited to 'qtsharp/src/bindings/static/QToolButton.cs')
-rw-r--r--qtsharp/src/bindings/static/QToolButton.cs38
1 files changed, 19 insertions, 19 deletions
diff --git a/qtsharp/src/bindings/static/QToolButton.cs b/qtsharp/src/bindings/static/QToolButton.cs
index 200c0c99..596f6369 100644
--- a/qtsharp/src/bindings/static/QToolButton.cs
+++ b/qtsharp/src/bindings/static/QToolButton.cs
@@ -1,4 +1,4 @@
// TTQToolButton.cs - A Qt to C# binding.
//
// Copyright (C) 2002 Adam Treat (manyoso@yahoo.com)
//
@@ -26,11 +26,11 @@ namespace Qt {
using System;
using System.Runtime.InteropServices;
- public class TTQToolButton : TTQButton, IDisposable {
+ public class TQToolButton : TQButton, IDisposable {
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern IntPtr qt_new_QToolButton (IntPtr parent, string name);
- public TTQToolButton (TTQWidget parent, string name) : this (TQNull.Instance)
+ public TQToolButton (TQWidget parent, string name) : this (TQNull.Instance)
{
rawObject = qt_new_QToolButton (parent != null ? parent.RawObject : IntPtr.Zero, name);
@@ -43,7 +43,7 @@ namespace Qt {
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern IntPtr qt_new_QToolButton1 (IntPtr iconSet, IntPtr textLabel, IntPtr groupText, IntPtr receiver, string slot, IntPtr parent, string name);
- public TTQToolButton (TTQIconSet iconSet, TTQString textLabel, TTQString groupText, TTQObject receiver, string slot, TTQToolBar parent, string name) : this (TQNull.Instance)
+ public TQToolButton (TQIconSet iconSet, TQString textLabel, TQString groupText, TQObject receiver, string slot, TQToolBar parent, string name) : this (TQNull.Instance)
{
rawObject = qt_new_QToolButton1 (iconSet.RawObject, textLabel.RawObject, groupText.RawObject, IntPtr.Zero, null, parent != null ? parent.RawObject : IntPtr.Zero, name);
Connect( this, TQT_SIGNAL("clicked()"), receiver, slot );
@@ -58,7 +58,7 @@ namespace Qt {
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern IntPtr qt_new_QToolButton2 (Qt.ArrowType type, IntPtr parent, string name);
- public TTQToolButton (Qt.ArrowType type, TTQWidget parent, string name) : this (TQNull.Instance)
+ public TQToolButton (Qt.ArrowType type, TQWidget parent, string name) : this (TQNull.Instance)
{
rawObject = qt_new_QToolButton2 (type, parent != null ? parent.RawObject : IntPtr.Zero, name);
@@ -69,19 +69,19 @@ namespace Qt {
Connect (this, TQT_SIGNAL ("destroyed ()"), TQT_SLOT ("NativeDestroyed ()"));
}
- public TTQToolButton (TTQWidget parent) : this (parent, "") {}
+ public TQToolButton (TQWidget parent) : this (parent, "") {}
- internal TTQToolButton () : this (TQNull.Instance) {}
+ internal TQToolButton () : this (TQNull.Instance) {}
- internal TTQToolButton (IntPtr ptr) : this (TQNull.Instance)
+ internal TQToolButton (IntPtr ptr) : this (TQNull.Instance)
{
rawObject = ptr;
RegisterObject(this);
}
- internal TTQToolButton (TQNull dummy) : base (TQNull.Instance) {}
+ internal TQToolButton (TQNull dummy) : base (TQNull.Instance) {}
- ~TTQToolButton ()
+ ~TQToolButton ()
{
Dispose (false);
}
@@ -116,7 +116,7 @@ namespace Qt {
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern void qt_QToolButton_setTextLabel (IntPtr raw, IntPtr arg1, bool arg2);
- public void SetTextLabel (TTQString arg1, bool arg2)
+ public void SetTextLabel (TQString arg1, bool arg2)
{
if (disposed)
throw new ObjectDisposedException (this+": Attempted use of disposed object");
@@ -156,7 +156,7 @@ namespace Qt {
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern void qt_QToolButton_setTextLabel1 (IntPtr raw, IntPtr arg1);
- public void SetTextLabel (TTQString arg1)
+ public void SetTextLabel (TQString arg1)
{
if (disposed)
throw new ObjectDisposedException (this+": Attempted use of disposed object");
@@ -166,7 +166,7 @@ namespace Qt {
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern void qt_QToolButton_setIconSet (IntPtr raw, IntPtr set);
- public void SetIconSet (TTQIconSet set)
+ public void SetIconSet (TQIconSet set)
{
if (disposed)
throw new ObjectDisposedException (this+": Attempted use of disposed object");
@@ -176,7 +176,7 @@ namespace Qt {
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern void qt_QToolButton_setIconSet1 (IntPtr raw, IntPtr set, bool on);
- public void SetIconSet (TTQIconSet set, bool on)
+ public void SetIconSet (TQIconSet set, bool on)
{
if (disposed)
throw new ObjectDisposedException (this+": Attempted use of disposed object");
@@ -186,12 +186,12 @@ namespace Qt {
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern IntPtr qt_QToolButton_iconSet (IntPtr raw, bool on);
- public TTQIconSet IconSet (bool on)
+ public TQIconSet IconSet (bool on)
{
if (disposed)
throw new ObjectDisposedException (this+": Attempted use of disposed object");
- return LookupObject (qt_QToolButton_iconSet (rawObject, on), typeof (TTQIconSet)) as TTQIconSet;
+ return LookupObject (qt_QToolButton_iconSet (rawObject, on), typeof (TQIconSet)) as TQIconSet;
}
[DllImport("libqtc", CharSet=CharSet.Ansi)]
@@ -246,7 +246,7 @@ namespace Qt {
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern void qt_QToolButton_drawButtonLabel (IntPtr raw, IntPtr arg1);
- protected void DrawButtonLabel (TTQPainter arg1)
+ protected void DrawButtonLabel (TQPainter arg1)
{
if (disposed)
throw new ObjectDisposedException (this+": Attempted use of disposed object");
@@ -266,7 +266,7 @@ namespace Qt {
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern bool qt_QToolButton_eventFilter (IntPtr raw, IntPtr o, IntPtr e);
- protected bool EventFilter (TTQObject o, TTQEvent e)
+ protected bool EventFilter (TQObject o, TQEvent e)
{
if (disposed)
throw new ObjectDisposedException (this+": Attempted use of disposed object");
@@ -276,7 +276,7 @@ namespace Qt {
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern void qt_QToolButton_paletteChange (IntPtr raw, IntPtr arg1);
- protected void PaletteChange (TTQPalette arg1)
+ protected void PaletteChange (TQPalette arg1)
{
if (disposed)
throw new ObjectDisposedException (this+": Attempted use of disposed object");
@@ -1,4 +1,4 @@
-// TTQToolButton.cs - A Qt to C# binding.
+// TQToolButton.cs - A Qt to C# binding.
//
// Copyright (C) 2002 Adam Treat (manyoso@yahoo.com)